use crate::server::auth;
use dioxus::prelude::*;

#[component]
pub fn Auth() -> Element {
    let mut register = use_signal(|| false);

    rsx! {
        div {
            class: "card w-full max-w-lg bg-base-200 shadow-xl mx-auto mt-20",
            div {
                class: "card-body",
                div {
                    role: "tablist",
                    class: "tabs tabs-boxed bg-base-100",
                    button { onclick: move |_| register.set(false), role: "tab", class: "tab", class: if !register() { "tab-active" }, "Sign In" },
                    button { onclick: move |_| register.set(true), role: "tab", class: "tab", class: if register() { "tab-active" }, "Register" },
                }
                if register() {
                    Register {}
                } else {
                    Signin {}
                }
            }
        }
    }
}

#[component]
fn Signin() -> Element {
    let mut email = use_signal(|| "".to_string());
    let mut password = use_signal(|| "".to_string());

    rsx! {
        form {
            class: "card-body",
            prevent_default: "oninput",
            onsubmit: move |_| async move { if let Ok(_user_id) = auth::signin(email(), password()).await {
            } },
            div {
                class: "form-control",
                label {
                    class: "label",
                    span { class: "label-text", "Email" },
                },
                input {
                    r#type: "email",
                    placeholder: "email",
                    class: "input input-bordered",
                    required: true,
                    value: "{email}",
                    oninput: move |event| email.set(event.value())
                },
            },
            div {
                class: "form-control",
                label {
                    class: "label",
                    span { class: "label-text", "Password" },
                },
                input {
                    r#type: "password",
                    placeholder: "password",
                    class: "input input-bordered",
                    required: true,
                    value: "{password}",
                    oninput: move |event| password.set(event.value())
                },
                label {
                    class: "label",
                    a { class: "label-text-alt link link-hover", "Forgot password?" },
                },
            },
            div {
                class: "form-control mt-6",
                button {
                    class: "btn btn-primary",
                    "Sign In",
                },
            },
        }
    }
}

#[component]
fn Register() -> Element {
    let mut email = use_signal(|| "".to_string());
    let mut password = use_signal(|| "".to_string());
    let mut confirm_password = use_signal(|| "".to_string());

    rsx! {
        form {
            class: "card-body",
            prevent_default: "oninput",
            onsubmit: move |_| async move { if let Ok(user_id) = auth::register(email(), password()).await {
                println!("Registered new user: {user_id}");
            } },
            div {
                class: "form-control",
                label {
                    class: "label",
                    span { class: "label-text", "Email" },
                },
                input {
                    r#type: "email",
                    placeholder: "email",
                    class: "input input-bordered",
                    required: true,
                    value: "{email}",
                    oninput: move |event| email.set(event.value())
                },
            },
            div {
                class: "form-control",
                label {
                    class: "label",
                    span { class: "label-text", "Password" },
                },
                input {
                    r#type: "password",
                    placeholder: "password",
                    class: "input input-bordered",
                    required: true,
                    value: "{password}",
                    oninput: move |event| password.set(event.value())
                },
            },
            div {
                class: "form-control",
                label {
                    class: "label",
                    span { class: "label-text", "Confirm password" },
                },
                input {
                    r#type: "password",
                    placeholder: "password",
                    class: "input input-bordered",
                    required: true,
                    value: "{confirm_password}",
                    oninput: move |event| confirm_password.set(event.value())
                },
            },
            div {
                class: "form-control mt-6",
                button {
                    class: "btn btn-primary",
                    "Register",
                },
            },
        }
    }
}
