pub mod modpack;

use crate::server::modpack::Modpack;
use crate::Route;
use dioxus::prelude::*;

#[component]
pub fn Modpacks() -> Element {
    let modpacks = use_resource(|| async move { get_modpacks().await });

    rsx! {
        div {
            class: "max-w-7xl px-2 w-full mx-auto",
            h2 { class: "text-2xl font-bold mt-10", "Modpacks" }
            div {
                class: "flex flex-wrap gap-8 mt-10",
                match &*modpacks.read_unchecked() {
                    Some(Ok(response)) => rsx! {
                        for modpack in response {
                            ModpackCard { modpack: modpack.to_owned() }
                        }
                    },
                    Some(Err(_)) => rsx! { "Loading modpacks failed" },
                    None => rsx! { "Loading modpacks... " },
                }
            }
        }
    }
}

#[derive(PartialEq, Props, Clone)]
pub struct ModpackCardProps {
    modpack: Modpack,
}

#[component]
pub fn ModpackCard(props: ModpackCardProps) -> Element {
    rsx! {
        Link {
            to: Route::Modpack { id: props.modpack.id },
            class: "card w-[25rem] bg-base-200 hover:bg-base-300 hover:cursor-pointer shadow-xl transition-all",
            div {
                class: "card-body",
                h2 { class: "card-title", "{props.modpack.name}" },
                div {
                    "For Minecraft ",
                    b { "{props.modpack.game_version}" },
                    " with ",
                    b { "{props.modpack.modloader}" },
                }
            }
        }
    }
}

#[server]
async fn get_modpacks() -> Result<Vec<Modpack>, ServerFnError> {
    use crate::server::auth::User;

    let user = User::from_cookie().await?;

    Modpack::get_all(user.id).await
}
