use dioxus::prelude::*;

use crate::server::modpack::Modpack;

#[component]
pub fn Modpack(id: String) -> Element {
    let modpack = use_resource(move || {
        to_owned![id];
        async move { get_modpack(id).await }
    });

    rsx! {
        div {
            class: "max-w-xl w-full mx-auto",
            match &*modpack.read_unchecked() {
                Some(Ok(response)) => rsx! {
                    Modpackview { modpack: response.to_owned() }
                },
                Some(Err(_)) => rsx! {
                    "Modpack not found"
                },
                None => rsx! { "Loading..." },
            }

        }
    }
}

#[component]
fn Modpackview(modpack: Modpack) -> Element {
    rsx! {
        h1 { class: "text-2xl font-bold mt-20", "{modpack.name}"}
        div {
            class: "mt-10",
            "For Minecraft ",
            b { "{modpack.game_version}" },
            " with ",
            b { "{modpack.modloader}" },
        }
    }
}

#[server]
async fn get_modpack(id: String) -> Result<Modpack, ServerFnError> {
    use crate::server::auth::User;

    User::from_cookie().await?;

    Modpack::get(id).await
}
