#![allow(non_snake_case)]
mod components;
mod modrinth;
mod server;

use dioxus::prelude::*;
use manganis::*;
use tracing::{info, Level};

use components::home::Home;
use components::layout::authenticated::Authenticated;
use components::modpacks::modpack::Modpack;
use components::modpacks::Modpacks;
use components::new::New;
use server::auth;

pub type UserState = Resource<Result<auth::User, ServerFnError>>;

#[derive(Clone, Routable)]
pub enum Route {
    #[layout(Authenticated)]
    #[route("/modpacks")]
    Modpacks {},
    #[route("/modpacks/:id")]
    Modpack { id: String },
    #[route("/new")]
    New {},
    #[end_layout]
    #[route("/")]
    Home {},
}

fn main() {
    // Init logger
    dioxus_logger::init(Level::INFO).expect("failed to init logger");

    const _: &str = manganis::mg!(file("assets/tailwind.css"));

    #[cfg(feature = "server")]
    {
        use axum::routing::*;

        tokio::runtime::Runtime::new()
            .unwrap()
            .block_on(async move {
                // Connect to databse
                server::surrealdb::connect()
                    .await
                    .expect("Database connection failed");

                tracing::info!("Database connection succesfull");

                // Create axum app
                let app = Router::new()
                    .serve_dioxus_application(ServeConfig::builder().build(), || {
                        VirtualDom::new(app)
                    })
                    .await;

                // Run axum app
                let addr = std::net::SocketAddr::from(([127, 0, 0, 1], 3000));
                let listener = tokio::net::TcpListener::bind(&addr).await.unwrap();

                axum::serve(listener, app.into_make_service())
                    .await
                    .unwrap();
            })
    }

    launch(app);
}

fn app() -> Element {
    let user = use_resource(auth::get_current_user);

    use_context_provider(|| user);

    rsx! {
        Router::<Route> {},
    }
}
