use once_cell::sync::Lazy;
use surrealdb::engine::local::{Db, SpeeDb};
use surrealdb::Surreal;

pub static DB: Lazy<Surreal<Db>> = Lazy::new(|| Surreal::init());

pub async fn connect() -> surrealdb::Result<()> {
    DB.connect::<SpeeDb>("./database").await?;

    DB.use_ns("xvmcmm").use_db("xvmcmm").await?;

    define_schema().await?;

    Ok(())
}

pub async fn define_schema() -> surrealdb::Result<()> {
    // Define user table
    let sql = "
        DEFINE TABLE user SCHEMAFULL;

        DEFINE FIELD email ON TABLE user TYPE string
            ASSERT string::is::email($value) VALUE string::lowercase($value);
        DEFINE FIELD password ON TABLE user TYPE string;
        DEFINE INDEX userEmailIndex ON TABLE user COLUMNS email UNIQUE;
    ";

    DB.query(sql).await?;

    // Define session table
    let sql = "
        DEFINE TABLE session SCHEMAFULL;

        DEFINE FIELD user ON TABLE session TYPE record;
        DEFINE FIELD token ON TABLE session TYPE string VALUE rand::string(32);
        DEFINE FIELD expires ON TABLE session TYPE datetime VALUE time::now() + 1w;

        DEFINE INDEX sessionTokenIndex ON TABLE session COLUMNS token UNIQUE;
    ";

    DB.query(sql).await?;

    Ok(())
}
